==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/Diki/DiaryDayList.pm <==
#
# WiKicker
#
#  DiaryDayList.pm
#
#
# Copyright (C) 2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: DiaryDayList.pm,v 1.1 2004/05/30 04:18:30 naney Exp $
#
#

package WiKicker::Diki::DiaryDayList;

use 5.005;
use strict;
use Carp;
use WiKicker::Diki::DiaryDay;

sub new {
  my ($class, %param) = @_;

  my $self = bless { updated => 0 }, $class;
  if (exists $param{article_list}) {
    $self->_initialize_by_article_list($param{article_list});
    return $self;
  }

  return $self;
}

sub updated {
  my ($self, $value) = @_;

  if (defined $value) {
    return $self->{updated} = $value;
  }
  return $self->{updated};
}

sub _initialize_by_article_list {
  my ($self, $article_list) = @_;

  for my $article (@$article_list) {
    $self->add_article($article);
  }
}

sub get_article {
  my ($self, $article_id) = @_;

  $article_id =~ /^(\d\d\d\d-\d\d-\d\d)/;
  my $date = $1;
  return $self->{day}->{$date}->get_article($article_id);
}

sub add_article {
  my ($self, $article) = @_;

  croak unless $article->isa('WiKicker::Diki::DiaryArticle');
  my $date = $article->date;
  unless ($date) {
    croak "no date attribute";
  }
  unless ($date =~ /^\d\d\d\d-\d\d-\d\d$/) {
    croak "Invalid date attribute: $date: " . $article->id;
  }
  unless (exists $self->{day}->{$date}) {
    $self->{day}->{$date} = WiKicker::Diki::DiaryDay->new(date=> $date);
  }
  $self->{day}->{$date}->add_article($article);
}

sub size {
  my $self = shift;

  return scalar(keys %{$self->{day}});
}

sub list {
  my $self = shift;

  my @date_list = keys %{$self->{day}};
  @date_list = sort { $b cmp $a } @date_list;

  return map {$self->{day}->{$_}} @date_list;
}

sub top_article {
  my $self = shift;

  my @list = $self->list;
  for my $day (@list) {
    my $article = $day->top_article;
    if (defined $article) {
      return $article;
    }
  }
  return undef;
}

sub article_last_modified_set {
  my $self = shift;

  my %result;
  for my $date (keys %{$self->{day}}) {
    my $set = $self->{day}->{$date}->article_last_modified_set;
    for my $article_id (keys %$set) {
      $result{$article_id} = $set->{$article_id};
    }
  }
  return \%result;
}

sub article_term_list_modified_set {
  my $self = shift;

  my %result;
  for my $date (keys %{$self->{day}}) {
    my $set = $self->{day}->{$date}->article_term_list_modified_set;
    for my $article_id (keys %$set) {
      $result{$article_id} = $set->{$article_id};
    }
  }
  return \%result;
}

sub html_title {
  my $self = shift;

  my $article = $self->top_article;
  if (defined $article) {
    return $article->title;
  }
  return '';
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/Diki/DiaryDayList.pm <==
#
# WiKicker
#
#  DiaryDayList.pm
#
#
# Copyright (C) 2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: DiaryDayList.pm,v 1.4 2005/03/13 11:24:30 naney Exp $
#
#

package WiKicker::Diki::DiaryDayList;

use 5.005;
use strict;
use Carp;
use WiKicker::Diki::DiaryDay;

sub new {
  my ($class, %param) = @_;

  my $self = bless { updated => 0 }, $class;
  if (exists $param{article_list}) {
    $self->_initialize_by_article_list($param{article_list});
    return $self;
  }

  return $self;
}

sub updated {
  my ($self, $value) = @_;

  if (defined $value) {
    return $self->{updated} = $value;
  }
  return $self->{updated};
}

sub _initialize_by_article_list {
  my ($self, $article_list) = @_;

  for my $article (@$article_list) {
    $self->add_article($article);
  }
}

sub get_article {
  my ($self, $article_id) = @_;

  $article_id =~ /^(\d\d\d\d-\d\d-\d\d)/;
  my $date = $1;
  return $self->{day}->{$date}->get_article($article_id);
}

sub add_article {
  my ($self, $article) = @_;

  croak unless $article->isa('WiKicker::Diki::DiaryArticle');
  my $date = $article->date;
  unless ($date) {
    croak 'no date attribute';
  }
  unless ($date =~ /^\d\d\d\d-\d\d-\d\d$/) {
    croak "Invalid date attribute: $date: " . $article->id;
  }
  unless (exists $self->{day}->{$date}) {
    $self->{day}->{$date} = WiKicker::Diki::DiaryDay->new(date=> $date);
  }
  $self->{day}->{$date}->add_article($article);
}

sub remove_article {
  my ($self, $article_id) = @_;

  unless ($article_id =~ /^(\d\d\d\d-\d\d-\d\d)/) {
    croak 'Invalid article_id ' . $article_id;
  }
  my $date = $1;

  $self->{day}->{$date}->remove_article($article_id);

  if ($self->{day}->{$date}->size == 0) {
    delete $self->{day}->{$date};
  }
}

sub size {
  my $self = shift;

  return scalar(keys %{$self->{day}});
}

sub list {
  my $self = shift;

  my @date_list = keys %{$self->{day}};
  @date_list = sort { $a cmp $b } @date_list;

  return map {$self->{day}->{$_}} @date_list;
}

sub top_article {
  my $self = shift;

  my @list = $self->list;
  for my $day (reverse @list) {
    my $article = $day->top_article;
    if (defined $article) {
      return $article;
    }
  }
  return undef;
}

sub article_last_modified_set {
  my $self = shift;

  my %result;
  for my $date (keys %{$self->{day}}) {
    my $set = $self->{day}->{$date}->article_last_modified_set;
    for my $article_id (keys %$set) {
      $result{$article_id} = $set->{$article_id};
    }
  }
  return \%result;
}

sub article_term_list_modified_set {
  my $self = shift;

  my %result;
  for my $date (keys %{$self->{day}}) {
    my $set = $self->{day}->{$date}->article_term_list_modified_set;
    for my $article_id (keys %$set) {
      $result{$article_id} = $set->{$article_id};
    }
  }
  return \%result;
}

sub html_title {
  my $self = shift;

  my $article = $self->top_article;
  if (defined $article) {
    return $article->title . ' (' . $article->date . ')';
  }
  return '';
}

1;
